# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
卢旺达语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r'Ukwa kane', '4月'),
    (r'Iminota', '分钟'),
]
FUZZY_REGEX_LIST = []