# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
乌克兰语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r"Січень", "1月"),
    (r"Лютий", "2月"),
    (r"Березень", "3月"),
    (r'квітня|Квітень', '4月'),
    (r"Травень", "5月"),
    (r"Червень", "6月"),
    (r"Липень", "7月"),
    (r"Серпень", "8月"),
    (r"Вересень", "9月"),
    (r"Жовтень", "10月"),
    (r"Листопад", "11月"),
    (r"Грудень", "12月"),

]

FUZZY_REGEX_LIST = [
    r"(?P<bH>\d+)\s*годин\(и\) тому",
    r"(?P<bH>\d+)\s*години\) тому",
    r"(?P<bM>\d+)\s*хвилин\(и\) тому",
    r"(?P<bM>\d+)\s*хвилини\) тому",
]
