# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/4/20

"""
阿塞拜疆语
"""

ACCURATE_REGEX_LIST = [

]
FUZZY_REGEX_LIST = []
SUB_TRANSLATE = [
    (r'əvvəl', '前'),
    (r'saat', '小时'),
]
